diff mbox series

[v2,22/27] rcu: Rename dyntick_save_progress_counter() into eqs_save_progress_counter()

Message ID 20240430091740.1826862-23-vschneid@redhat.com (mailing list archive)
State New
Headers show
Series context_tracking, rcu: Spring cleaning renaming | expand

Commit Message

Valentin Schneider April 30, 2024, 9:17 a.m. UTC
The context_tracking.state RCU_DYNTICKS subvariable has been renamed to
RCU_WATCHING, and the 'dynticks' prefix can be dropped without losing any
meaning.

Signed-off-by: Valentin Schneider <vschneid@redhat.com>
---
 .../RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg        | 2 +-
 .../RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg         | 2 +-
 Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg   | 2 +-
 .../RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg        | 2 +-
 kernel/rcu/tree.c                                         | 8 ++++----
 5 files changed, 8 insertions(+), 8 deletions(-)

Comments

Frederic Weisbecker May 8, 2024, 1:21 p.m. UTC | #1
Le Tue, Apr 30, 2024 at 11:17:26AM +0200, Valentin Schneider a écrit :
> The context_tracking.state RCU_DYNTICKS subvariable has been renamed to
> RCU_WATCHING, and the 'dynticks' prefix can be dropped without losing any
> meaning.
> 
> Signed-off-by: Valentin Schneider <vschneid@redhat.com>
> ---
>  .../RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg        | 2 +-
>  .../RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg         | 2 +-
>  Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg   | 2 +-
>  .../RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg        | 2 +-
>  kernel/rcu/tree.c                                         | 8 ++++----
>  5 files changed, 8 insertions(+), 8 deletions(-)
> 
> diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg
> index 423df00c4df9d..961b2595241fe 100644
> --- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg
> +++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg
> @@ -528,7 +528,7 @@
>         font-style="normal"
>         y="-8652.5312"
>         x="2466.7822"
> -       xml:space="preserve">dyntick_save_progress_counter()</text>
> +       xml:space="preserve">eqs_save_progress_counter()</text>
>      <text
>         style="font-size:192px;font-style:normal;font-weight:bold;text-anchor:start;fill:#000000;stroke-width:0.025in;font-family:Courier"
>         id="text202-7-2-7-2-0"
> diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg
> index d82a77d03d8cc..9a8e7d1686ce1 100644
> --- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg
> +++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg
> @@ -844,7 +844,7 @@
>       font-style="normal"
>       y="1547.8876"
>       x="4417.6396"
> -     xml:space="preserve">dyntick_save_progress_counter()</text>
> +     xml:space="preserve">eqs_save_progress_counter()</text>
>    <g
>       style="fill:none;stroke-width:0.025in"
>       transform="translate(6501.9719,-10685.904)"
> diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg
> index 53e0dc2a2c793..40e6686962de1 100644
> --- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg
> +++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg
> @@ -2974,7 +2974,7 @@
>         font-style="normal"
>         y="38114.047"
>         x="-334.33856"
> -       xml:space="preserve">dyntick_save_progress_counter()</text>
> +       xml:space="preserve">eqs_save_progress_counter()</text>
>      <g
>         style="fill:none;stroke-width:0.025in"
>         transform="translate(1749.9916,25880.249)"
> diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg
> index 4fa7506082bfe..14313aeb8affd 100644
> --- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg
> +++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg
> @@ -516,7 +516,7 @@
>         font-style="normal"
>         y="-8652.5312"
>         x="2466.7822"
> -       xml:space="preserve">dyntick_save_progress_counter()</text>
> +       xml:space="preserve">eqs_save_progress_counter()</text>
>      <text
>         style="font-size:192px;font-style:normal;font-weight:bold;text-anchor:start;fill:#000000;stroke-width:0.025in;font-family:Courier"
>         id="text202-7-2-7-2-0"
> diff --git a/kernel/rcu/tree.c b/kernel/rcu/tree.c
> index 73b95240a1a6c..2037daf0298d0 100644
> --- a/kernel/rcu/tree.c
> +++ b/kernel/rcu/tree.c
> @@ -764,11 +764,11 @@ static void rcu_gpnum_ovf(struct rcu_node *rnp, struct rcu_data *rdp)
>  }
>  
>  /*
> - * Snapshot the specified CPU's dynticks counter so that we can later
> + * Snapshot the specified CPU's RCU_WATCHING counter so that we can later
>   * credit them with an implicit quiescent state.  Return 1 if this CPU
>   * is in dynticks idle mode, which is an extended quiescent state.
>   */
> -static int dyntick_save_progress_counter(struct rcu_data *rdp)
> +static int eqs_save_progress_counter(struct rcu_data *rdp)

rcu_watching_snap_save() ?

>  {
>  	rdp->watching_snap = rcu_watching_snap(rdp->cpu);
>  	if (rcu_watching_in_eqs(rdp->watching_snap)) {
> @@ -782,7 +782,7 @@ static int dyntick_save_progress_counter(struct rcu_data *rdp)
>  /*
>   * Returns positive if the specified CPU has passed through a quiescent state
>   * by virtue of being in or having passed through an dynticks idle state since
> - * the last call to dyntick_save_progress_counter() for this same CPU, or by
> + * the last call to eqs_save_progress_counter() for this same CPU, or by
>   * virtue of having been offline.
>   *
>   * Returns negative if the specified CPU needs a force resched.
> @@ -1981,7 +1981,7 @@ static void rcu_gp_fqs(bool first_time)
>  
>  	if (first_time) {
>  		/* Collect dyntick-idle snapshots. */
> -		force_qs_rnp(dyntick_save_progress_counter);
> +		force_qs_rnp(eqs_save_progress_counter);
>  	} else {
>  		/* Handle dyntick-idle and offline CPUs. */
>  		force_qs_rnp(rcu_implicit_dynticks_qs);

And then I'm tempted to propose rcu_watching_snap_recheck() instead of
rcu_implicit_dynticks_qs().

Thanks.

> -- 
> 2.43.0
>
diff mbox series

Patch

diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg
index 423df00c4df9d..961b2595241fe 100644
--- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg
+++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-dyntick.svg
@@ -528,7 +528,7 @@ 
        font-style="normal"
        y="-8652.5312"
        x="2466.7822"
-       xml:space="preserve">dyntick_save_progress_counter()</text>
+       xml:space="preserve">eqs_save_progress_counter()</text>
     <text
        style="font-size:192px;font-style:normal;font-weight:bold;text-anchor:start;fill:#000000;stroke-width:0.025in;font-family:Courier"
        id="text202-7-2-7-2-0"
diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg
index d82a77d03d8cc..9a8e7d1686ce1 100644
--- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg
+++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp-fqs.svg
@@ -844,7 +844,7 @@ 
      font-style="normal"
      y="1547.8876"
      x="4417.6396"
-     xml:space="preserve">dyntick_save_progress_counter()</text>
+     xml:space="preserve">eqs_save_progress_counter()</text>
   <g
      style="fill:none;stroke-width:0.025in"
      transform="translate(6501.9719,-10685.904)"
diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg
index 53e0dc2a2c793..40e6686962de1 100644
--- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg
+++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-gp.svg
@@ -2974,7 +2974,7 @@ 
        font-style="normal"
        y="38114.047"
        x="-334.33856"
-       xml:space="preserve">dyntick_save_progress_counter()</text>
+       xml:space="preserve">eqs_save_progress_counter()</text>
     <g
        style="fill:none;stroke-width:0.025in"
        transform="translate(1749.9916,25880.249)"
diff --git a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg
index 4fa7506082bfe..14313aeb8affd 100644
--- a/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg
+++ b/Documentation/RCU/Design/Memory-Ordering/TreeRCU-hotplug.svg
@@ -516,7 +516,7 @@ 
        font-style="normal"
        y="-8652.5312"
        x="2466.7822"
-       xml:space="preserve">dyntick_save_progress_counter()</text>
+       xml:space="preserve">eqs_save_progress_counter()</text>
     <text
        style="font-size:192px;font-style:normal;font-weight:bold;text-anchor:start;fill:#000000;stroke-width:0.025in;font-family:Courier"
        id="text202-7-2-7-2-0"
diff --git a/kernel/rcu/tree.c b/kernel/rcu/tree.c
index 73b95240a1a6c..2037daf0298d0 100644
--- a/kernel/rcu/tree.c
+++ b/kernel/rcu/tree.c
@@ -764,11 +764,11 @@  static void rcu_gpnum_ovf(struct rcu_node *rnp, struct rcu_data *rdp)
 }
 
 /*
- * Snapshot the specified CPU's dynticks counter so that we can later
+ * Snapshot the specified CPU's RCU_WATCHING counter so that we can later
  * credit them with an implicit quiescent state.  Return 1 if this CPU
  * is in dynticks idle mode, which is an extended quiescent state.
  */
-static int dyntick_save_progress_counter(struct rcu_data *rdp)
+static int eqs_save_progress_counter(struct rcu_data *rdp)
 {
 	rdp->watching_snap = rcu_watching_snap(rdp->cpu);
 	if (rcu_watching_in_eqs(rdp->watching_snap)) {
@@ -782,7 +782,7 @@  static int dyntick_save_progress_counter(struct rcu_data *rdp)
 /*
  * Returns positive if the specified CPU has passed through a quiescent state
  * by virtue of being in or having passed through an dynticks idle state since
  * the last call to dyntick_save_progress_counter() for this same CPU, or by
  * virtue of having been offline.
  *
  * Returns negative if the specified CPU needs a force resched.
@@ -1981,7 +1981,7 @@  static void rcu_gp_fqs(bool first_time)
 
 	if (first_time) {
 		/* Collect dyntick-idle snapshots. */
-		force_qs_rnp(dyntick_save_progress_counter);
+		force_qs_rnp(eqs_save_progress_counter);
 	} else {
 		/* Handle dyntick-idle and offline CPUs. */
 		force_qs_rnp(rcu_implicit_dynticks_qs);
@@ -782,7 +782,7 @@  static int dyntick_save_progress_counter(struct rcu_data *rdp)
  * Returns positive if the specified CPU has passed through a quiescent state
  * by virtue of being in or having passed through an dynticks idle state since
- * the last call to dyntick_save_progress_counter() for this same CPU, or by
+ * the last call to eqs_save_progress_counter() for this same CPU, or by
  * virtue of having been offline.
  *